==> pynpoint-0.7.0.tar.gz: pynpoint-0.7.0/pynpoint/__init__.py <==
import warnings

from pynpoint.core.pypeline import Pypeline

from pynpoint.processing.background import SimpleBackgroundSubtractionModule, \
                                           MeanBackgroundSubtractionModule, \
                                           LineSubtractionModule, \
                                           NoddingBackgroundModule

from pynpoint.processing.badpixel import BadPixelSigmaFilterModule, \
                                         BadPixelInterpolationModule, \
                                         BadPixelMapModule, \
                                         BadPixelTimeFilterModule, \
                                         ReplaceBadPixelsModule

from pynpoint.processing.basic import SubtractImagesModule, \
                                      AddImagesModule, \
                                      RotateImagesModule

from pynpoint.processing.centering import StarExtractionModule, \
                                          StarAlignmentModule, \
                                          StarCenteringModule, \
                                          ShiftImagesModule, \
                                          WaffleCenteringModule

from pynpoint.processing.darkflat import DarkCalibrationModule, \
                                         FlatCalibrationModule

from pynpoint.processing.fluxposition import FakePlanetModule, \
                                             SimplexMinimizationModule, \
                                             FalsePositiveModule, \
                                             MCMCsamplingModule, \
                                             AperturePhotometryModule

from pynpoint.processing.frameselection import RemoveFramesModule, \
                                               FrameSelectionModule, \
                                               RemoveLastFrameModule, \
                                               RemoveStartFramesModule

from pynpoint.processing.limits import ContrastCurveModule

from pynpoint.processing.pcabackground import PCABackgroundPreparationModule, \
                                              PCABackgroundSubtractionModule, \
                                              DitheringBackgroundModule

from pynpoint.processing.psfpreparation import PSFpreparationModule, \
                                               AngleInterpolationModule, \
                                               AngleCalculationModule, \
                                               SortParangModule, \
                                               SDIpreparationModule

from pynpoint.processing.psfsubtraction import PcaPsfSubtractionModule, \
                                               ClassicalADIModule

from pynpoint.processing.resizing import CropImagesModule, \
                                         ScaleImagesModule, \
                                         AddLinesModule, \
                                         RemoveLinesModule

from pynpoint.processing.stacksubset import StackAndSubsetModule, \
                                            MeanCubeModule, \
                                            StackCubesModule, \
                                            DerotateAndStackModule, \
                                            CombineTagsModule

from pynpoint.processing.timedenoising import CwtWaveletConfiguration, \
                                              DwtWaveletConfiguration, \
                                              WaveletTimeDenoisingModule, \
                                              TimeNormalizationModule

from pynpoint.readwrite.fitsreading import FitsReadingModule

from pynpoint.readwrite.fitswriting import FitsWritingModule

from pynpoint.readwrite.hdf5reading import Hdf5ReadingModule

from pynpoint.readwrite.hdf5writing import Hdf5WritingModule

from pynpoint.readwrite.textwriting import AttributeWritingModule, \
                                           ParangWritingModule, \
                                           TextWritingModule

from pynpoint.readwrite.textreading import ParangReadingModule, \
                                           AttributeReadingModule

warnings.simplefilter('always', DeprecationWarning)

__author__ = 'Tomas Stolker, Markus Bonse, Sascha Quanz, and Adam Amara'
__license__ = 'GPLv3'
__version__ = '0.7.0'
__maintainer__ = 'Tomas Stolker'
__email__ = 'tomas.stolker@phys.ethz.ch'
__status__ = 'Development'

==> pynpoint-0.8.0.tar.gz: pynpoint-0.8.0/pynpoint/__init__.py <==
import warnings

from pynpoint.core.pypeline import Pypeline

from pynpoint.processing.background import SimpleBackgroundSubtractionModule, \
                                           MeanBackgroundSubtractionModule, \
                                           LineSubtractionModule, \
                                           NoddingBackgroundModule

from pynpoint.processing.badpixel import BadPixelSigmaFilterModule, \
                                         BadPixelInterpolationModule, \
                                         BadPixelMapModule, \
                                         BadPixelTimeFilterModule, \
                                         ReplaceBadPixelsModule

from pynpoint.processing.basic import SubtractImagesModule, \
                                      AddImagesModule, \
                                      RotateImagesModule, \
                                      RepeatImagesModule

from pynpoint.processing.centering import StarAlignmentModule, \
                                          StarCenteringModule, \
                                          FitCenterModule, \
                                          ShiftImagesModule, \
                                          WaffleCenteringModule

from pynpoint.processing.darkflat import DarkCalibrationModule, \
                                         FlatCalibrationModule

from pynpoint.processing.extract import StarExtractionModule, \
                                        ExtractBinaryModule

from pynpoint.processing.fluxposition import FakePlanetModule, \
                                             SimplexMinimizationModule, \
                                             FalsePositiveModule, \
                                             MCMCsamplingModule, \
                                             AperturePhotometryModule

from pynpoint.processing.frameselection import RemoveFramesModule, \
                                               FrameSelectionModule, \
                                               RemoveLastFrameModule, \
                                               RemoveStartFramesModule, \
                                               ImageStatisticsModule, \
                                               FrameSimilarityModule, \
                                               SelectByAttributeModule

from pynpoint.processing.limits import ContrastCurveModule, \
                                       MassLimitsModule

from pynpoint.processing.pcabackground import PCABackgroundPreparationModule, \
                                              PCABackgroundSubtractionModule, \
                                              DitheringBackgroundModule

from pynpoint.processing.psfpreparation import PSFpreparationModule, \
                                               AngleInterpolationModule, \
                                               AngleCalculationModule, \
                                               SortParangModule, \
                                               SDIpreparationModule

from pynpoint.processing.psfsubtraction import PcaPsfSubtractionModule, \
                                               ClassicalADIModule

from pynpoint.processing.resizing import CropImagesModule, \
                                         ScaleImagesModule, \
                                         AddLinesModule, \
                                         RemoveLinesModule

from pynpoint.processing.stacksubset import StackAndSubsetModule, \
                                            MeanCubeModule, \
                                            StackCubesModule, \
                                            DerotateAndStackModule, \
                                            CombineTagsModule

from pynpoint.processing.timedenoising import CwtWaveletConfiguration, \
                                              DwtWaveletConfiguration, \
                                              WaveletTimeDenoisingModule, \
                                              TimeNormalizationModule

from pynpoint.readwrite.fitsreading import FitsReadingModule

from pynpoint.readwrite.fitswriting import FitsWritingModule

from pynpoint.readwrite.hdf5reading import Hdf5ReadingModule

from pynpoint.readwrite.hdf5writing import Hdf5WritingModule

from pynpoint.readwrite.textwriting import AttributeWritingModule, \
                                           ParangWritingModule, \
                                           TextWritingModule

from pynpoint.readwrite.textreading import ParangReadingModule, \
                                           AttributeReadingModule

from pynpoint.readwrite.nearreading import NearReadingModule

warnings.simplefilter('always', DeprecationWarning)

__author__ = 'Tomas Stolker, Markus Bonse, Sascha Quanz, and Adam Amara'
__license__ = 'GPLv3'
__version__ = '0.8.0'
__maintainer__ = 'Tomas Stolker'
__email__ = 'tomas.stolker@phys.ethz.ch'
__status__ = 'Development'
